==> kdegraphics-3.2.3.tar.bz2: kdegraphics-3.2.3/ksvg/dom/SVGLangSpace.h <==
/*
    Copyright (C) 2001-2003 KSVG Team
    This file is part of the KDE project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

#ifndef SVGLangSpace_H
#define SVGLangSpace_H

#include <dom/dom_string.h>

namespace KSVG
{

class SVGLangSpaceImpl;
class SVGLangSpace 
{ 
public:
	SVGLangSpace(const SVGLangSpace &other);
	SVGLangSpace &operator=(const SVGLangSpace &other);
	SVGLangSpace(SVGLangSpaceImpl *other);
	~SVGLangSpace();

	void setXmllang(const DOM::DOMString &xmllang);
	DOM::DOMString xmllang() const;

	void setXmlspace(const DOM::DOMString &xmlspace);
	DOM::DOMString xmlspace() const;

	// Internal! - NOT PART OF THE SVG SPECIFICATION
	SVGLangSpaceImpl *handle() const { return impl; }

protected:
	SVGLangSpace();

private:
	SVGLangSpaceImpl *impl;
};

};

#endif

// vim:ts=4:noet

==> kdegraphics-3.5.0.tar.bz2: kdegraphics-3.5.0/ksvg/dom/SVGLangSpace.h <==
/*
    Copyright (C) 2001-2003 KSVG Team
    This file is part of the KDE project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef SVGLangSpace_H
#define SVGLangSpace_H

#include <dom/dom_string.h>

namespace KSVG
{

class SVGLangSpaceImpl;
class SVGLangSpace 
{ 
public:
	SVGLangSpace(const SVGLangSpace &other);
	SVGLangSpace &operator=(const SVGLangSpace &other);
	SVGLangSpace(SVGLangSpaceImpl *other);
	~SVGLangSpace();

	void setXmllang(const DOM::DOMString &xmllang);
	DOM::DOMString xmllang() const;

	void setXmlspace(const DOM::DOMString &xmlspace);
	DOM::DOMString xmlspace() const;

	// Internal! - NOT PART OF THE SVG SPECIFICATION
	SVGLangSpaceImpl *handle() const { return impl; }

protected:
	SVGLangSpace();

private:
	SVGLangSpaceImpl *impl;
};

}

#endif

// vim:ts=4:noet
